@@ -29,29 +29,7 @@ prep_valuelabels_from_data <-
 
   util_expect_data_frame(study_data)
 
-  if (requireNamespace("tibble", quietly = TRUE)) {
-    if (tibble::is_tibble(study_data)) {
-      study_data <- as.data.frame(study_data)
-    }
-  } else if (inherits(study_data, "tbl_df")) { # nocov start
-    util_warning(
-      c(
-        "%s looks like a tibble. However, the package %s seems not to be",
-        "available, which is quite strange.",
-        "I cannot convert the tibble to a data.frame therefore.",
-        "Tibbles do not always work like base R data.frames (see %s), so",
-        "this can cause errors,",
-        "because %s expects %s in base R data.frames, not in tibbles."
-      ),
-      dQuote("study_data"),
-      dQuote("tibble"),
-      dQuote("https://r4ds.had.co.nz/tibbles.html#tibbles-vs.data.frame"),
-      dQuote("dataquieR"),
-      dQuote("study_data"),
-      applicability_problem = FALSE
-    )
-  } # nocov end
-
+  study_data <- util_cast_off(study_data, "study_data")
 
   if ((length(study_data) == 0) || !is.character(resp_vars)) {
     util_error(
@@ -60,13 +38,14 @@ prep_valuelabels_from_data <-
   }
 
   if (!(all(resp_vars %in% colnames(study_data)))) {
-    util_warning(c(
+    util_message(c(
       "The following %s are missing from the %s.",
       "Won't return a type for them: %s"),
       dQuote("resp_vars"),
       dQuote("study_data"),
       sQuote(resp_vars[!(resp_vars %in% colnames(study_data))]),
-      applicability_problem = TRUE
+      applicability_problem = TRUE,
+      intrinsic_applicability_problem = TRUE
     )
   }
 
