@@ -12,7 +12,7 @@ util_find_first_externally_called_functions_in_stacktrace <-
   function(sfs = rev(sys.frames()), cls = rev(sys.calls())) {
   first <- util_find_external_functions_in_stacktrace(sfs, cls)
   if (length(first) == 0) {
-    length(sfs) - 1
+    NA_integer_
   } else {
     head(first, 1) - 2
   }
