@@ -22,7 +22,7 @@ test_that("acc_multivariate_outlier works with 3 args", {
     perl = TRUE
   )
 
-  expect_warning(
+  expect_message(
     res1 <-
       acc_multivariate_outlier(variable_group = c("v00014", "v00006"),
                          study_data = study_data, meta_data = meta_data),
@@ -77,7 +77,7 @@ test_that("acc_multivariate_outlier works with label_col", {
     perl = TRUE
   )
 
-  expect_warning(
+  expect_message(
     res1 <-
       acc_multivariate_outlier(variable_group = c("CRP_0", "GLOBAL_HEALTH_VAS_0"),
                                label_col = LABEL,
@@ -114,3 +114,7 @@ test_that("acc_multivariate_outlier works with label_col", {
     "acc_mv_outlierCRP0GLOBHEAVA0",
                               res1$SummaryPlot)
 })
+
+test_that("criteria is robust", {
+
+})
