@@ -15,4 +15,14 @@ test_that("util_check_data_type works", {
                                     DATA_TYPES$DATETIME))
   expect_true(util_check_data_type(as.POSIXct("2020-11-11 17:10:07 CET"),
                                    DATA_TYPES$DATETIME))
+  expect_error(util_check_data_type(as.POSIXct("2020-11-11 17:10:07 CET"),
+                                   "xyz"),
+               regexp = ".+xyz.+ is not a known data type.")
+
+  expect_true(all(2 == util_check_data_type("2020-11-11 17:10:07 CET",
+                                    DATA_TYPES$DATETIME,
+                                    check_convertible = TRUE)))
+  expect_true(all(0 == util_check_data_type("not a date",
+                                            DATA_TYPES$DATETIME,
+                                            check_convertible = TRUE)))
 })
